@@ -10,7 +10,7 @@ from wagtail.documents.edit_handlers import DocumentChooserPanel
 from wagtail.documents.models import Document
 
 
-class DocumentPage(Page):
+class ADocumentPage(Page):
     document = models.ForeignKey(
         Document,
         null=True,
@@ -34,3 +34,6 @@ class DocumentPage(Page):
             return response
         except Exception:
             raise Http404("")
+
+    class Meta:
+        abstract = True
